Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(335)

Unified Diff: chrome/test/chromedriver/chrome/device_metrics_override_manager.h

Issue 251933005: [ChromeDriver] Support mobile emulation on desktop Chrome. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/test/chromedriver/chrome/device_metrics_override_manager.h
diff --git a/chrome/test/chromedriver/chrome/geolocation_override_manager.h b/chrome/test/chromedriver/chrome/device_metrics_override_manager.h
similarity index 52%
copy from chrome/test/chromedriver/chrome/geolocation_override_manager.h
copy to chrome/test/chromedriver/chrome/device_metrics_override_manager.h
index 0ce63539d5fef7ab4a456d1e3e54f396fd3076ee..b0ea1d670adcfe194a5995c153369e97cbd4198f 100644
--- a/chrome/test/chromedriver/chrome/geolocation_override_manager.h
+++ b/chrome/test/chromedriver/chrome/device_metrics_override_manager.h
@@ -1,9 +1,9 @@
-// Copyright (c) 2013 The Chromium Authors. All rights reserved.
+// Copyright (c) 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_TEST_CHROMEDRIVER_CHROME_GEOLOCATION_OVERRIDE_MANAGER_H_
-#define CHROME_TEST_CHROMEDRIVER_CHROME_GEOLOCATION_OVERRIDE_MANAGER_H_
+#ifndef CHROME_TEST_CHROMEDRIVER_CHROME_DEVICE_METRICS_OVERRIDE_MANAGER_H_
+#define CHROME_TEST_CHROMEDRIVER_CHROME_DEVICE_METRICS_OVERRIDE_MANAGER_H_
#include <string>
@@ -17,17 +17,17 @@ class DictionaryValue;
}
class DevToolsClient;
-struct Geoposition;
+struct DeviceMetrics;
class Status;
// Overrides the geolocation, if requested, for the duration of the
// given |DevToolsClient|'s lifetime.
-class GeolocationOverrideManager : public DevToolsEventListener {
+class DeviceMetricsOverrideManager : public DevToolsEventListener {
public:
- explicit GeolocationOverrideManager(DevToolsClient* client);
- virtual ~GeolocationOverrideManager();
+ explicit DeviceMetricsOverrideManager(DevToolsClient* client);
+ virtual ~DeviceMetricsOverrideManager();
- Status OverrideGeolocation(const Geoposition& geoposition);
+ Status OverrideDeviceMetrics(const DeviceMetrics& DeviceMetrics);
stgao 2014/05/03 00:15:20 Maybe we don't have to add this function, as we do
sam.rawlins 2014/05/06 23:51:46 Done.
// Overridden from DevToolsEventListener:
virtual Status OnConnected(DevToolsClient* client) OVERRIDE;
@@ -39,9 +39,9 @@ class GeolocationOverrideManager : public DevToolsEventListener {
Status ApplyOverrideIfNeeded();
DevToolsClient* client_;
- scoped_ptr<Geoposition> overridden_geoposition_;
+ scoped_ptr<DeviceMetrics> overridden_device_metrics_;
- DISALLOW_COPY_AND_ASSIGN(GeolocationOverrideManager);
+ DISALLOW_COPY_AND_ASSIGN(DeviceMetricsOverrideManager);
};
-#endif // CHROME_TEST_CHROMEDRIVER_CHROME_GEOLOCATION_OVERRIDE_MANAGER_H_
+#endif // CHROME_TEST_CHROMEDRIVER_CHROME_DEVICE_METRICS_OVERRIDE_MANAGER_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -17,17 +17,17 @@ class DictionaryValue;
class Status;
-// Overrides the geolocation, if requested, for the duration of the
+// Overrides the device metrics, if requested, for the duration of the
// given |DevToolsClient|'s lifetime.